@@ -49,7 +49,7 @@ async def validation_exception_handler(request: Request, exc: RequestValidationE
         errors.extend(
             {
                 "area": error.get("loc", ("", ""))[0],
-                "variable": error.get("loc", ("", ""))[1],
+                "variable": error.get("loc", ("", ""))[1] if len(error.get("loc", ("", ""))) > 1 else "",
                 "message": error.get("msg"),
                 "type": error.get("type"),
             }
