@@ -1,28 +1,23 @@
 import asyncio
 import datetime
 from io import BytesIO
-from typing import List, Optional, Union, Iterator
+from typing import Iterator, List, Optional, Union
 
 from fastapi import UploadFile
-from google.cloud.storage import Client as GCPClient
+from google.auth import compute_engine
+from google.auth.exceptions import RefreshError
+from google.auth.transport import requests
 from google.cloud.exceptions import Conflict, GoogleCloudError, NotFound
+from google.cloud.storage import Client as GCPClient
 from google.cloud.storage.bucket import Blob, Bucket
 
-from fa_common import (
-    StorageError,
-    force_async,
-    get_current_app,
-    get_settings,
-    logger as LOG,
-    sizeof_fmt,
-)
+from fa_common import StorageError, force_async, get_current_app, get_settings
+from fa_common import logger as LOG
+from fa_common import sizeof_fmt
 
 from .base_client import BaseClient
 from .model import File
 
-from google.auth.transport import requests
-from google.auth import compute_engine
-from google.auth.exceptions import RefreshError
 
 class GoogleStorageClient(BaseClient):
     """
@@ -117,7 +112,7 @@ class GoogleStorageClient(BaseClient):
             gs_uri = f"gs://{blob.bucket.name}/{blob.name}"
 
         name = path_segments[-1]
-        path = "/".join(path_segments[0:-1])
+        path = "/".join(path_segments[:-1])
 
         return File(
             id=blob.id,
@@ -161,11 +156,7 @@ class GoogleStorageClient(BaseClient):
         return scidra_file
 
     async def upload_file(
-        self,
-        file: UploadFile,
-        bucket_name: str,
-        parent_path: str = "",
-        timeout: int = 60
+        self, file: UploadFile, bucket_name: str, parent_path: str = "", timeout: int = 60
     ) -> File:
         bucket = await self._get_bucket(bucket_name)
         path = self.convert_path_in(parent_path, bucket_name)
@@ -176,7 +167,9 @@ class GoogleStorageClient(BaseClient):
         try:
             file.file.seek(0)
             # Increasing timeout instead of using default to allow processing of really large files.
-            await force_async(blob.upload_from_file)(file.file, content_type=file.content_type, timeout=timeout)
+            await force_async(blob.upload_from_file)(
+                file.file, content_type=file.content_type, timeout=timeout
+            )
         except GoogleCloudError as err:
             LOG.error(str(err))
             raise StorageError("Something went wrong uploadinf file {}", path + file.filename)
@@ -265,15 +258,23 @@ class GoogleStorageClient(BaseClient):
         expire_time = datetime.timedelta(hours=expire_time_hours)
 
         try:
-            # GCE signer does not work as expected causing generate_signed_url to fail without private key associated with service account supplied.
+            # GCE signer does not work as expected causing generate_signed_url to fail
+            # without private key associated with service account supplied.
             # This happens even when cloud run is executed with the service account.
             # See https://github.com/googleapis/google-auth-library-python/issues/50.
             # Current workaround is to supply the credentials as an argument.
             # See https://gist.github.com/jezhumble/91051485db4462add82045ef9ac2a0ec.
-            signing_credentials = compute_engine.IDTokenCredentials(requests.Request(), "", service_account_email=self.gcp_storage._credentials.service_account_email)
-            url = blob.generate_signed_url(expiration=expire_time, credentials=signing_credentials, version="v4")
+            signing_credentials = compute_engine.IDTokenCredentials(
+                requests.Request(),
+                "",
+                service_account_email=self.gcp_storage._credentials.service_account_email,
+            )
+            url = blob.generate_signed_url(
+                expiration=expire_time, credentials=signing_credentials, version="v4"
+            )
         except RefreshError:
-            # Refresh error may occur if Compute engine metadata is unavailable, in which case signing is done using json supplied.
+            # Refresh error may occur if Compute engine metadata is unavailable, in which case signing
+            # is done using json supplied.
             # Retaining this so that existing usage that does not utilise cloud run does not break.
             url = blob.generate_signed_url(expiration=expire_time, version="v4")
         LOG.info(f"Created url: {url} for file download")
