@@ -1,7 +1,7 @@
+import asyncio
 import functools
 import importlib
 import logging
-import asyncio
 import os
 import sys
 from datetime import datetime
@@ -140,17 +140,13 @@ async def async_get(url, auth: str = None, json_only=True, retry: bool = True):
         if response.content_type == "application/json":
             return await response.json()
         elif json_only:
-            logger.warning(
-                f"Async call {url} was expecting JSON but got: {await response.text()}"
-            )
+            logger.warning(f"Async call {url} was expecting JSON but got: {await response.text()}")
             if retry:
                 logger.warning(f"Retrying get {url} in 2 seconds")
                 await asyncio.sleep(2)
                 return await async_get(url, auth, json_only, retry=False)
             else:
-                raise ValueError(
-                    f"get {url} is returning a non json response: {await response.text()}"
-                )
+                raise ValueError(f"get {url} is returning a non json response: {await response.text()}")
         else:
             return await response.text()
 
